#-*- coding: utf-8 -*-

from django import template
from django.conf import settings
from django.template.base import Token
from django.template.loader_tags import do_include
from django.utils.text import capfirst
from pymorphy import get_morph

register = template.Library()
morph = get_morph(settings.PYMORPHY_DICTS['ru']['dir'])


@register.filter
def plural_from_object(source, obj):
    len_ = len(obj[0])
    if len_ == 1:
        return source
    return morph.pluralize_inflected_ru(source.upper(), len_).lower()


@register.filter
def plural_from_object_with_num(source, obj):
    len_ = len(obj[0])
    if len_ == 1:
        return source
    return '%d %s' % (len_, morph.pluralize_inflected_ru(source.upper(), len_).lower())


@register.filter
def plural_by_length(source, length):
    if length == 1:
        return source
    return morph.pluralize_inflected_ru(source.upper(), length).lower()


@register.simple_tag
def extratrans(source, type_='app'):
    if type_ == 'caption':
        captions = {
            'title': u'Панель администрирования сайта',
            'branding': u'Администрирование',
            'home': u'Главная'
        }
        captions.update(getattr(settings, 'ADMIN_CAPTIONS', {}))
        return captions.get(source, source)
    elif type_ == 'app':
        trans = getattr(settings, 'VERBOSE_APPS_NAMES', {}).get(source.lower(), source)
        return capfirst(trans) if source.istitle() else trans
    return source


@register.tag('render_breadcrumbs')
def do_render_breadcrumbs(parser, token):
    include = 'include "admin/breadcrumbs.html" with app_label=%s'
    return do_include(parser, Token(token.token_type, include % token.split_contents()[1]))



#-*- coding: utf-8 -*-

import re

from django.conf import settings
from django.utils.text import capfirst
from pymorphy import get_morph

morph = get_morph(settings.PYMORPHY_DICTS['ru']['dir'])


def message_wrapper(func):
    def wrapper(self, request, message):
        gram_info = morph.get_graminfo(self.model._meta.verbose_name.upper())[0]
        if -1 != message.find(u'"'):
            # message about some action with a single element

            words = [w for w in re.split("( |\\\".*?\\\".*?)", message) if w.strip()]
            form = gram_info['info'][:gram_info['info'].find(',')]
            message = u' '.join(words[:2])
            for word in words[2:]:
                if not word.isdigit():
                    word = word.replace(".", "").upper()
                    try:
                        info = morph.get_graminfo(word)[0]
                        if u'КР_ПРИЛ' != info['class']:
                            word = morph.inflect_ru(word, form).lower()
                        elif 0 <= info['info'].find(u'мр'):
                            word = morph.inflect_ru(word, form, u'КР_ПРИЧАСТИЕ').lower()
                        else:
                            word = word.lower()
                    except IndexError:
                        word = word.lower()
                message += u' ' + word
        else:
            # message about some action with a group of elements

            num = int(re.search(r'\d', message).group(0))
            words = message.split(u' ')
            message = words[0]
            pos = gram_info['info'].find(',')
            form = gram_info['info'][:pos] + u',' + u'ед' if 1 == num else u'мн'
            for word in words[1:]:
                if not word.isdigit():
                    word = word.replace(".", "").upper()
                    info = morph.get_graminfo(word)[0]
                    if u'КР_ПРИЛ' != info['class']:
                        word = morph.pluralize_inflected_ru(word, num).lower()
                    else:
                        word = morph.inflect_ru(word, form, u'КР_ПРИЧАСТИЕ').lower()
                message += u' ' + word

        message += '.'
        return func(self, request, capfirst(message))
    return wrapper



from django.contrib import admin

from .decorators import message_wrapper


class ModelAdmin(admin.ModelAdmin):
    @message_wrapper
    def message_user(self, *args, **kwargs):
        return super(ModelAdmin, self).message_user(*args, **kwargs)



#-*- coding: utf-8 -*-
import os
from distutils.core import setup

name = 'django-extended-admin-ru'
inner_dir = 'admin_extended_ru'

version = __import__(inner_dir).__version__
bitbucket_url = "http://bitbucket.org/masterzeb/%s/" % name
packages, data_files = [], []


def read(filename):
    return open(os.path.join(os.path.dirname(__file__), 'README')).read()


for dirpath, dirnames, filenames in os.walk(inner_dir):
    # Ignore dirnames that start with '.'
    for i, dirname in enumerate(dirnames):
        if dirname.startswith('.'):
            del dirnames[i]
    if '__init__.py' in filenames:
        pkg = dirpath.replace(os.path.sep, '.')
        if os.path.altsep:
            pkg = pkg.replace(os.path.altsep, '.')
        packages.append(pkg)
    elif filenames:
        prefix = dirpath[(len(inner_dir) + 1):]
        for file_name in filenames:
            data_files.append(os.path.join(prefix, file_name))

setup(
    name=name,
    version=version,
    author='Denis Savasteev',
    author_email='devmaster.zeb@gmail.com',
    description=u'Полностью переведенный на русский язык административный интерфейс Django',
    long_description=read('README'),
    license="BSD",

    packages=packages,
    package_dir={inner_dir: inner_dir},
    package_data={inner_dir: data_files},

    url=bitbucket_url,
    download_url='%sdownloads/%s-%s.tar.gz' % (bitbucket_url, name, version),

    install_requires=['django-extended-admin', 'pymorphy'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django']
)
